@@ -94,11 +94,16 @@ sub end_element {
 	my ($self,$hash) = @_;
 	my $elem = lc($hash->{LocalName});
 	my $text = $hash->{Text};
+	if( defined $text )
+	{
+		$text =~ s/^\s+//;
+		$text =~ s/\s+$//;
+	}
 	if( $elem eq 'identifier' ) {
 		die "HTTP::OAI::Header parse error: Empty identifier\n" unless $text;
 		$self->identifier($text);
 	} elsif( $elem eq 'datestamp' ) {
-		warn "HTTP::OAI::Header parse warning: Empty datestamp\n" unless $text;
+		warn "HTTP::OAI::Header parse warning: Empty datestamp for ".$self->identifier."\n" unless $text;
 		$self->datestamp($text);
 	} elsif( $elem eq 'setspec' ) {
 		$self->setSpec($text);
@@ -156,6 +161,6 @@ Returns the list of setSpecs and optionally appends a new setSpec C<$setSpec> (O
 
 =item $dom_fragment = $id->generate()
 
-Act as a SAX driver (use C<$h->set_handler()> to specify the filter to pass events to).
+Act as a SAX driver (use C<< $h->set_handler() >> to specify the filter to pass events to).
 
 =back
