@@ -1,6 +1,8 @@
 package HTTP::OAI::MetadataFormat;
 
-use HTTP::OAI::Metadata;
+use strict;
+use warnings;
+
 use HTTP::OAI::SAXHandler qw/ :SAX /;
 
 use vars qw( @ISA );
@@ -49,6 +51,11 @@ sub end_element {
 	my ($self,$hash) = @_;
 	$self->SUPER::end_element($hash);
 	my $elem = lc($hash->{LocalName});
+	if( defined $hash->{Text} )
+	{
+		$hash->{Text} =~ s/^\s+//;
+		$hash->{Text} =~ s/\s+$//;
+	}
 	if( $elem eq 'metadataprefix' ) {
 		$self->metadataPrefix($hash->{Text});
 	} elsif( $elem eq 'schema' ) {
