@@ -1,7 +1,8 @@
 package HTTP::OAI::Repository;
 
 use strict;
-use 5.005; # 5.004 seems to have problems with use base
+use warnings;
+
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 require Exporter;
 
@@ -215,7 +216,7 @@ Using the OAI-PERL library in a repository context requires the user to build th
 	# Include a description (an XML::LibXML Dom object)
 	$r->description(new HTTP::OAI::Metadata(dom=>$dom));
 
-	my $r = HTTP::OAI::GetRecord->new(
+	my $r = HTTP::OAI::Record->new(
 		header=>HTTP::OAI::Header->new(
 			identifier=>'oai:myrepo:10',
 			datestamp=>'2004-10-01'
