@@ -125,11 +125,12 @@ sub parse_file {
 	$self->code(200);
 	$self->message('parse_file');
 	
-	my $parser = XML::SAX::ParserFactory->parser(
+	my $parser = XML::LibXML::SAX->new(
 		Handler=>HTTP::OAI::SAXHandler->new(
 			Handler=>$self->headers
 	));
 
+HTTP::OAI::Debug::trace( $self->verb . " " . ref($parser) . "->parse_file( ".ref($fh)." )" );
 	$self->headers->set_handler($self);
 	$USE_EVAL ?
 		eval { $parser->parse_file($fh) } :
@@ -160,18 +161,22 @@ sub parse_string {
 	$self->code(200);
 	$self->message('parse_string');
 	do {
-		my $parser = XML::SAX::ParserFactory->parser(
+		my $parser = XML::LibXML::SAX->new(
 			Handler=>HTTP::OAI::SAXHandler->new(
 				Handler=>$self->headers
 		));
+HTTP::OAI::Debug::trace( $self->verb . " " . ref($parser) . "->parse_string(...)" );
 
 		$self->headers->set_handler($self);
-		$USE_EVAL ?
-			eval { $parser->parse_string($str) } :
-			$parser->parse_string($str);
+		eval {
+			local $SIG{__DIE__};
+			$parser->parse_string( $str )
+		};
 		$self->headers->set_handler(undef);
+		undef $@ if $@ && $@ =~ /^done\n/;
 
 		if( $@ ) {
+			die $@ if !$USE_EVAL; # rethrow
 			$self->errors(new HTTP::OAI::Error(
 				code=>'parseError',
 				message=>"Error while parsing XML: $@",
@@ -206,11 +211,18 @@ sub resume {
 	my $token = $args{resumptionToken} || Carp::confess "Required argument resumptionToken is undefined";
 	my $verb = $args{verb} || $self->verb || Carp::confess "Required argument verb is undefined";
 
+	if( !ref($token) or !$token->isa( "HTTP::OAI::ResumptionToken" ) )
+	{
+		$token = HTTP::OAI::ResumptionToken->new( resumptionToken => $token );
+	}
+
+HTTP::OAI::Debug::trace( "'" . $token->resumptionToken . "'" );
+
 	my $response;
 	%args = (
 		baseURL=>$ha->repository->baseURL,
 		verb=>$verb,
-		resumptionToken=>(ref $token ? $token->resumptionToken : $token),
+		resumptionToken=>$token->resumptionToken,
 	);
 	$self->headers->{_args} = \%args;
 
@@ -229,13 +241,11 @@ sub resume {
 					$tries = 0;
 				}
 			}
-			if( $HTTP::OAI::Harvester::DEBUG ) {
-				warn sprintf("Error resuming using token [%s] %d [%s]\n",
-					$args{resumptionToken},
-					$response->code,
-					$response->message
-				);
-			}
+HTTP::OAI::Debug::trace( sprintf("Error response to '%s': %d '%s'\n",
+	$args{resumptionToken},
+	$response->code,
+	$response->message
+	) );
 		}
 	} while(
 		!$response->is_success and
