@@ -1,6 +1,8 @@
 package HTTP::OAI::Set;
 
-use HTTP::OAI::Metadata;
+use strict;
+use warnings;
+
 use HTTP::OAI::SAXHandler qw/ :SAX /;
 
 use vars qw( @ISA );
@@ -46,7 +48,7 @@ sub start_element {
 	if( $elem eq 'setdescription' ) {
 		$self->setDescription(my $d = $self->{handlers}->{description}->new(version=>$self->version));
 		$self->set_handler($d);
-		$self->SUPER::start_document();
+		g_start_document($d);
 	}
 	$self->SUPER::start_element($hash);
 }
@@ -58,7 +60,8 @@ sub end_element {
 		die ref($self)." Parse error: Empty setSpec\n" unless $hash->{Text};
 		$self->setSpec($hash->{Text});
 	} elsif( $elem eq 'setname' ) {
-		die ref($self)." Parse error: Empty setName\n" unless $hash->{Text};
+		warn ref($self)." Parse error: Empty setName\n", return
+			unless $hash->{Text};
 		$self->setName($hash->{Text});
 	} elsif( $elem eq 'setdescription' ) {
 		$self->SUPER::end_document();
@@ -84,7 +87,7 @@ HTTP::OAI::Set - Encapsulates OAI set XML data
 
 These methods return respectively, the setSpec and setName of the OAI Set.
 
-=item $descs = $s->setDescription([$desc])
+=item @descs = $s->setDescription([$desc])
 
 Returns and optionally adds the list of set descriptions. Returns a reference to an array of L<HTTP::OAI::Description|HTTP::OAI::Description> objects.
 
